/*------------------------------------------------------------------------------*
 * Architecture & Implementation of DBMS                                        *
 *------------------------------------------------------------------------------*
 * Copyright 2019 Databases and Information Systems Group TU Dortmund          *
 *                                                                              *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS      *
 * OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,  *
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL      *
 * THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR         *
 * OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE,        *
 * ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR        *
 * OTHER DEALINGS IN THE SOFTWARE.                                              *
 *------------------------------------------------------------------------------*
 */

#include "base/simple_tables.h"
#include "operators/nested_loops_join.h"
#include "operators/index_nested_loops_join.h"
#include "benchmarks/join_workload.h"
#include "base/clock.h"

#include <iostream>
int main()
{
    aidbms::benchmarks::JoinWorkload line_items("workloads/lineitems.tbl", "LineItem", {"order_id", "part_id"});
    aidbms::benchmarks::JoinWorkload orders("workloads/orders.tbl", "Order", {"order_id", "customer_id"});

    aidbms::operators::NestedLoopsJoin nested_loops_join;
    {
        aidbms::base::Clock c("Nested Loops Join");
        Relation U = nested_loops_join.join(line_items, orders, {"order_id", "order_id"});
        std::cout << "Nested Loops Join found " << U.size() << " tuples." << std::endl;
    }

    aidbms::operators::IndexNestedLoopsJoin index_nested_loops_join;
    {
        aidbms::base::Clock c("Index Nested Loops Join");
        Relation V = index_nested_loops_join.join(line_items, orders, {"order_id", "order_id"});
        std::cout << "Index Nested Loops Join found " << V.size() << " tuples." << std::endl;
    }

    return 0;
}
