/*------------------------------------------------------------------------------*
 * Architecture & Implementation of DBMS                                        *
 *------------------------------------------------------------------------------*
 * Copyright 2019 Databases and Information Systems Group TU Dortmund          *
 *                                                                              *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS      *
 * OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,  *
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL      *
 * THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR         *
 * OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE,        *
 * ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR        *
 * OTHER DEALINGS IN THE SOFTWARE.                                              *
 *------------------------------------------------------------------------------*
 */

#include <benchmarks/join_workload.h>
#include <string>
#include <regex>
#include <cstdlib>
#include <random>
#include <iostream>

using namespace aidbms::benchmarks;

JoinWorkload::JoinWorkload(const char *workload_file_name, std::string relation_name, std::vector<std::string> column_names)
    : _relation(column_names, relation_name)
{
    std::regex request_regex("(\\d+)\\t(\\d+).*");

    match_function on_match = [this](std::smatch &match) {
        auto column1 = aidbms::simple_tables::VALUE_TYPE(std::atoi(match.str(1).c_str()));
        auto column2 = aidbms::simple_tables::VALUE_TYPE(std::atoi(match.str(2).c_str()));

        this->_relation.addTuple({column1, column2});
    };

    this->parse(workload_file_name, request_regex, on_match);
}
